package com.yideb.audit.task;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateUtil;
import com.yideb.audit.entity.vo.TopDataVo;
import com.yideb.audit.service.ITopDataService;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Date;

/**
 * <b>Application name：</b> yideb-audit-statistic <br>
 * <b>Application describing： </b> <br>
 * <b>Copyright：</b> Copyright &copy; 2019 明医众禾科技（北京）有限责任公司 版权所有。<br>
 * <b>Company：</b> 明医众禾科技（北京）有限责任公司 <br>
 * <b>@Date：</b> 2020/8/5 18:36 <br>
 * <b>@author：</b> <a href="mailto:Lijing@miyzh.com"> Lijing </a> <br>
 */
@Component
public class TopScheduleTask {

	@Resource
	private ITopDataService topDataService;

	@Scheduled(cron = "0 0 * * * ?")
	public void execute() {
		// 数据容器
		TopDataVo dataVo = new TopDataVo();
		// 星期时间
		String weekStartTime = DateUtil.offsetDay(DateUtil.beginOfDay(new Date()), -6).toString(DatePattern.NORM_DATETIME_PATTERN);
		String weekEndTime = DateUtil.endOfDay(new Date()).toString(DatePattern.NORM_DATETIME_PATTERN);
		// 今天
		String todayStartTime = DateUtil.beginOfDay(new Date()).toString(DatePattern.NORM_DATETIME_PATTERN);
		String todayEndTime = DateUtil.endOfDay(new Date()).toString(DatePattern.NORM_DATETIME_PATTERN);

		// 累计注册药店
		Integer totalClinicRegCount = topDataService.queryClinicRegCount(null, null);
		// 累计审核处方
		Integer auditCount = topDataService.queryAuditCount(null, null);
		// 本周注册药店
		Integer weekClinicRegCount = topDataService.queryClinicRegCount(weekStartTime, weekEndTime);
		// 今日处方总量
		Integer todayAuditCount = topDataService.queryAuditCount(todayStartTime, todayEndTime);
		// 今日药店数量
		Integer todayClinicCount = topDataService.queryClinicCount(todayStartTime, todayEndTime);
		// 今日医生数量
		Integer todayDoctorCount = topDataService.queryDoctorCount(todayStartTime, todayEndTime);
		// 今日药师数量
		Integer todayPharmacistCount = topDataService.queryPharmacistCount(todayStartTime, todayEndTime);

		dataVo.setTotalClinicRegCount(totalClinicRegCount);
		dataVo.setAuditCount(auditCount);
		dataVo.setWeekClinicRegCount(weekClinicRegCount);
		dataVo.setTodayAuditCount(todayAuditCount);
		dataVo.setTodayClinicCount(todayClinicCount);
		dataVo.setTodayDoctorCount(todayDoctorCount);
		dataVo.setTodayPharmacistCount(todayPharmacistCount);

		// 写数据
	}

}
